@@ -12,10 +12,11 @@
 //! # live
 //! 启用 b 站直播相关 api，默认关闭
 //!
-//! # live-native-tls / live-rustls
-//! 设置 live 的 tls 后端。这个 feature 需要跟 native-tls / rustls 同时设置，因为目前 cargo 的
-//! [weak dependency features](https://doc.rust-lang.org/cargo/reference/unstable.html#weak-dependency-features)
-//! 还没 stable
+
+#[cfg(not(any(feature = "rustls", feature = "native-tls")))]
+compile_error!("至少应该启用一个 rustls 或是 native-tls features");
+#[cfg(all(feature = "rustls", feature = "native-tls"))]
+compile_error!("rustls 和 native-tls features 只能同时启用一个");
 
 #[macro_use]
 extern crate log;
